diff -ru a/modules/video_output/x11/x11.c b/modules/video_output/x11/x11.c
--- a/modules/video_output/x11/x11.c	2008-11-06 18:44:49.000000000 +0100
+++ b/modules/video_output/x11/x11.c	2008-11-06 17:31:04.000000000 +0100
@@ -66,16 +66,6 @@
     "Screen to use in fullscreen mode. For instance " \
     "set it to 0 for first screen, 1 for the second.")
 
-#define X11_EVENT_TEXT N_("key and mouse event handling at X11 plugin level.")
-#define X11_EVENT_LONGTEXT N_( \
-    "This parameter accepts values : 1 (full event handling support), " \
-    "2 (event handling only for fullscreen) or 3 (No event handling). "  \
-    "Full event handling support is the default value.")
-
-static const int pi_x11_event_values[] = { 1, 2, 3 };
-static const char *const ppsz_x11_event_descriptions[] =
-     { N_("FullSupport"), N_("Fullscreen-Only"), N_("None") };
-
 vlc_module_begin ()
     set_shortname( "X11" )
     set_category( CAT_VIDEO )
@@ -88,8 +78,6 @@
 #ifdef HAVE_XINERAMA
     add_integer ( "x11-xineramascreen", -1, NULL, SCREEN_TEXT, SCREEN_LONGTEXT, true )
 #endif
-    add_integer( "x11-event", 1, NULL, X11_EVENT_TEXT, X11_EVENT_LONGTEXT, true )
-        change_integer_list( pi_x11_event_values, ppsz_x11_event_descriptions, NULL )
     set_description( N_("X11 video output") )
     set_capability( "video output", 70 )
     set_callbacks( Activate, Deactivate )
diff -ru a/modules/video_output/x11/xcommon.c b/modules/video_output/x11/xcommon.c
--- a/modules/video_output/x11/xcommon.c	2008-11-06 18:44:49.000000000 +0100
+++ b/modules/video_output/x11/xcommon.c	2008-11-06 18:26:10.000000000 +0100
@@ -210,6 +210,9 @@
 
     vlc_mutex_init( &p_vout->p_sys->lock );
 
+    /* key and mouse event handling */
+    p_vout->p_sys->i_vout_event = var_CreateGetInteger( p_vout, "vout-event" );
+
     /* Open display, using the "display" config variable or the DISPLAY
      * environment variable */
     psz_display = config_GetPsz( p_vout, MODULE_STRING "-display" );
@@ -1529,22 +1532,21 @@
                            i_x, i_y, i_width, i_height );
     }
 
-    /* cursor hiding depending on --x11-event option
+    /* cursor hiding depending on --vout-event option
      *      activated if:
      *            value = 1 (Fullsupport) (default value)
      *         or value = 2 (Fullscreen-Only) and condition met
      */
-    int i_x11_event = var_CreateGetInteger( p_vout, "x11-event" );
-    bool b_x11_event = (    ( i_x11_event == 1 )
-                         || ( i_x11_event == 2 && p_vout->b_fullscreen )
-                       );
+    bool b_vout_event = (   ( p_vout->p_sys->i_vout_event == 1 )
+                         || ( p_vout->p_sys->i_vout_event == 2 && p_vout->b_fullscreen )
+                        );
 
     /* Autohide Cursour */
     if( mdate() - p_vout->p_sys->i_time_mouse_last_moved >
         p_vout->p_sys->i_mouse_hide_timeout )
     {
         /* Hide the mouse automatically */
-        if( b_x11_event && p_vout->p_sys->b_mouse_pointer_visible )
+        if( b_vout_event && p_vout->p_sys->b_mouse_pointer_visible )
         {
             ToggleCursor( p_vout );
         }
@@ -1800,17 +1802,15 @@
         }
     } while( !( b_expose && b_configure_notify && b_map_notify ) );
 
-    /* key and mouse events handling depending on --x11-event option
+    /* key and mouse events handling depending on --vout-event option
      *      activated if:
      *            value = 1 (Fullsupport) (default value)
      *         or value = 2 (Fullscreen-Only) and condition met
      */
-    int i_x11_event = var_CreateGetInteger( p_vout, "x11-event" );
-    bool b_x11_event = (    ( i_x11_event == 1 )
-                         || ( i_x11_event == 2 && p_vout->b_fullscreen )
-                       );
-
-    if ( b_x11_event )
+    bool b_vout_event = (   ( p_vout->p_sys->i_vout_event == 1 )
+                         || ( p_vout->p_sys->i_vout_event == 2 && p_vout->b_fullscreen )
+                        );
+    if ( b_vout_event )
         XSelectInput( p_vout->p_sys->p_display, p_win->base_window,
                       StructureNotifyMask | KeyPressMask |
                       ButtonPressMask | ButtonReleaseMask |
diff -ru a/modules/video_output/x11/xcommon.h b/modules/video_output/x11/xcommon.h
--- a/modules/video_output/x11/xcommon.h	2008-11-05 00:11:05.000000000 +0100
+++ b/modules/video_output/x11/xcommon.h	2008-11-06 18:50:06.000000000 +0100
@@ -222,6 +222,9 @@
     x11_window_t        original_window;
     x11_window_t        fullscreen_window;
 
+    /* key and mouse event handling */
+    int                 i_vout_event;  /* 1(Fullsupport), 2(FullscreenOnly), 3(none) */
+
     /* X11 generic properties */
     bool          b_altfullscreen;          /* which fullscreen method */
 #ifdef HAVE_SYS_SHM_H
diff -ru a/src/libvlc-module.c b/src/libvlc-module.c
--- a/src/libvlc-module.c	2008-11-05 00:11:09.000000000 +0100
+++ b/src/libvlc-module.c	2008-11-06 17:15:30.000000000 +0100
@@ -548,6 +548,16 @@
     "This avoids flooding the message log with debug output from the " \
     "video output synchronization mechanism.")
 
+#define VOUT_EVENT_TEXT N_("key and mouse event handling at vout level.")
+#define VOUT_EVENT_LONGTEXT N_( \
+    "This parameter accepts values : 1 (full event handling support), " \
+    "2 (event handling only for fullscreen) or 3 (No event handling). "  \
+    "Full event handling support is the default value.") 
+
+static const int pi_vout_event_values[] = { 1, 2, 3 };
+static const char *const ppsz_vout_event_descriptions[] =
+     { N_("FullSupport"), N_("Fullscreen-Only"), N_("None") };
+
 /*****************************************************************************
  * Input
  ****************************************************************************/
@@ -1523,6 +1533,8 @@
               SKIP_FRAMES_LONGTEXT, true );
     add_bool( "quiet-synchro", 0, NULL, QUIET_SYNCHRO_TEXT,
               QUIET_SYNCHRO_LONGTEXT, true );
+    add_integer( "vout-event", 1, NULL, VOUT_EVENT_TEXT, VOUT_EVENT_LONGTEXT, true )
+        change_integer_list( pi_vout_event_values, ppsz_vout_event_descriptions, NULL )
 #ifndef __APPLE__
     add_bool( "overlay", 1, NULL, OVERLAY_TEXT, OVERLAY_LONGTEXT, false )
 #endif
